@@ -33,6 +33,29 @@ from .protocol import (
     PROTOCOL_LEDENET_ORIGINAL,
 )
 
+MODEL_INFO_NAMES = {
+    "ZG-LX-FL": "Flood",  # Seen on 24w Flood light
+    "ZG-BL": "",  # unknown
+    "ZG-BL-IR": "IR",
+    "IR": "IR",
+    "ZG-BL-EH7W": "7w",
+    "ZG-BL-IH9WL": "9w RF",
+    "ZG-BL-IH9W": "9w RF",
+    "ZG-BL-CB1": "Ceiling",
+    "ZG-LX-EJ9W": "9w",  # This might be a ceiling light
+    "RF": "RF",
+    "LWS-BL": "Ceiling",
+    "LWS-LX-IR": "Ceiling IR",
+    "ZG-BL-611HZ": "",  # unknown
+    "ZG-BL-5V": "5v",
+    "ZG-LX": "",  # Seen on floor lamp, v2 addressable, and Single channel controller
+    "ZG-LX-UART": "",  # Seen on UK xmas lights 0x33, fairy controller, and lytworx
+    "ZG-BL-PWM": "Flood",  # Seen on 40w Flood Light
+    "ZG-ZW2": "",  # seen on 0x97 socket
+    "ZGIR44": "44 Key IR",
+    "IR_ZG": "IR",
+}
+
 
 @dataclass
 class MinVersionProtocol:
@@ -497,7 +520,7 @@ MODELS = [
         model_num=0x33,
         # 'AK001-ZJ100' == v3 - WIFI370 version
         # 'AK001-ZJ2104' == v7 supports turning on by effect/levels set
-        # 'AK001-ZJ2101' == v8
+        # 'AK001-ZJ2101' == v8 - no dimmable effects confirmed, confirmed auto on
         # "AK001-ZJ2145" == v9 # no rf support!
         # "AK001-ZJ2146" == v10 # rf support
         # "AK001-ZJ2148" == v10.63 # rf support
@@ -816,6 +839,15 @@ def _unknown_ledenet_model(model_num: int, fallback_protocol: str) -> LEDENETMod
     )
 
 
-def get_model_description(model_num: int) -> str:
+def get_model_description(model_num: int, model_info: Optional[str]) -> str:
     """Return the description for a model."""
-    return get_model(model_num).description
+    return format_model_description(get_model(model_num).description, model_info)
+
+
+def format_model_description(description: str, model_info: Optional[str]) -> str:
+    """Format the description for a model."""
+    if model_info:
+        extra = MODEL_INFO_NAMES.get(model_info)
+        if extra:
+            return f"{description} {extra}"
+    return description
